import { Component, HostListener, Output, EventEmitter, ViewChild } from '@angular/core';
import { Subject } from 'rxjs/Subject';
var TextInputAutocompleteMenuComponent = /** @class */ (function () {
    function TextInputAutocompleteMenuComponent() {
        this.closeMenu = new EventEmitter();
        this.selectChoice = new Subject();
        this.choiceLoading = false;
        this.startingY = 0;
        this.endY = 0;
        this.currentY = 0;
        this.itemHeight = 0;
        this.viewHeight = 0;
    }
    Object.defineProperty(TextInputAutocompleteMenuComponent.prototype, "choices", {
        get: function () {
            return this._choices;
        },
        set: function (choices) {
            this._choices = choices;
            if (choices.indexOf(this.activeChoice) === -1 && choices.length > 0) {
                this.activeChoice = choices[1];
            }
        },
        enumerable: true,
        configurable: true
    });
    TextInputAutocompleteMenuComponent.prototype.onArrowDown = function (event) {
        event.preventDefault();
        var index = this.choices.indexOf(this.activeChoice);
        if (this.itemHeight === 0 && this.dropdown.nativeElement.children[0]) {
            this.itemHeight = this.dropdown.nativeElement.children[0].clientHeight;
            this.viewHeight =
                this.dropdown.nativeElement.clientHeight - this.itemHeight * 3;
            this.currentY = -this.viewHeight;
        }
        this.currentY += this.itemHeight;
        if (this.endY === 0 || this.currentY < this.endY) {
            this.dropdown.nativeElement.scrollTo(0, this.currentY);
        }
        if (this.choices[index + 1]) {
            if (this.choices[index + 1].startsWith('---')) {
                if (this.choices[index + 2]) {
                    this.activeChoice = this._choices[index + 2];
                }
            }
            else {
                this.activeChoice = this._choices[index + 1];
            }
        }
        else {
            this.endY = this.currentY;
        }
    };
    TextInputAutocompleteMenuComponent.prototype.onArrowUp = function (event) {
        event.preventDefault();
        var index = this.choices.indexOf(this.activeChoice);
        if (this.itemHeight === 0 && this.dropdown.nativeElement.children[0]) {
            this.itemHeight = this.dropdown.nativeElement.children[0].clientHeight;
            this.viewHeight =
                this.dropdown.nativeElement.clientHeight - this.itemHeight * 3;
        }
        if (this.currentY < 0) {
            this.currentY = -this.viewHeight;
        }
        else {
            this.currentY -= this.itemHeight;
            this.dropdown.nativeElement.scrollTo(0, this.currentY);
        }
        if (this.choices[index - 1]) {
            if (this.choices[index - 1].startsWith('---')) {
                if (this.choices[index - 2]) {
                    this.activeChoice = this._choices[index - 2];
                }
                else {
                    // do nothing
                }
            }
            else {
                this.activeChoice = this._choices[index - 1];
            }
        }
    };
    TextInputAutocompleteMenuComponent.prototype.onEnter = function (event) {
        if (this.choices.indexOf(this.activeChoice) > -1) {
            event.preventDefault();
            this.selectChoice.next(this.activeChoice);
        }
    };
    TextInputAutocompleteMenuComponent.prototype.onEscPress = function (e) {
        this.closeMenu.emit();
    };
    TextInputAutocompleteMenuComponent.decorators = [
        { type: Component, args: [{
                    template: "\n    <ul #inputACMenu\n      *ngIf=\"choices?.length > 0\"\n      class=\"dropdown-menu\"\n      [style.top.px]=\"position?.top\"\n      [style.left.px]=\"position?.left\">\n      <li \n        *ngFor=\"let choice of choices\"\n        [ngStyle] = \"{'background-color': choice.startsWith('---') ? '#E0EFF6' : 'auto', \n                    'color': choice.startsWith('---') ? 'black' : 'auto'}\"\n        [class.active]=\"activeChoice === choice\">\n        <a\n          href=\"javascript:;\"\n          (click)=\"selectChoice.next(choice)\">\n          {{ choice }}\n        </a>\n      </li>\n    </ul>\n  ",
                    styles: [
                        "\n    .dropdown-menu {\n      display: block;\n      overflow: auto;\n      height: 200px;\n      resize: both;\n    }\n  "
                    ]
                },] },
    ];
    /** @nocollapse */
    TextInputAutocompleteMenuComponent.ctorParameters = function () { return []; };
    TextInputAutocompleteMenuComponent.propDecorators = {
        'dropdown': [{ type: ViewChild, args: ['inputACMenu',] },],
        'closeMenu': [{ type: Output },],
        'onArrowDown': [{ type: HostListener, args: ['document:keydown.ArrowDown', ['$event'],] },],
        'onArrowUp': [{ type: HostListener, args: ['document:keydown.ArrowUp', ['$event'],] },],
        'onEnter': [{ type: HostListener, args: ['document:keydown.Enter', ['$event'],] },],
        'onEscPress': [{ type: HostListener, args: ['document:keydown.Escape', ['$event'],] },],
    };
    return TextInputAutocompleteMenuComponent;
}());
export { TextInputAutocompleteMenuComponent };
//# sourceMappingURL=text-input-autocomplete-menu.component.js.map